@@ -28,8 +28,13 @@ class ftpUtil:
             transport = paramiko.Transport((self.__hostname, self.__host_port))
             transport.connect(username=self.__username_stud, password=self.__password_stud)
             sftp = paramiko.SFTPClient.from_transport(transport)
-            sftp.chdir(self.__remotedir_stud)
-            prj="P"+prj_id.zfill(6)
+            prj = "P" + prj_id.zfill(6)
+            remotepath=self.__remotedir_stud+prj
+            try:
+                sftp.chdir(remotepath)
+            except:
+                sftp.mkdir(remotepath)
+                sftp.chdir(remotepath)
             stud=stud_id.zfill(11)
             no=no_file.zfill(2)
             remote_file=prj+"_" + stud +"_" + no +file_type
